@@ -22,6 +22,7 @@ from lollypop.database import Database
 from lollypop.define import Lp, Type
 from lollypop.objects import Track
 from lollypop.sqlcursor import SqlCursor
+from lollypop.localized import LocalizedCollation
 
 
 class Playlists(GObject.GObject):
@@ -130,7 +131,8 @@ class Playlists(GObject.GObject):
         with SqlCursor(self) as sql:
             result = sql.execute("SELECT rowid, name\
                                   FROM playlists\
-                                  ORDER BY name COLLATE NOCASE")
+                                  ORDER BY name\
+                                  COLLATE NOCASE COLLATE LOCALIZED")
             return list(result)
 
     def get_last(self):
@@ -161,9 +163,9 @@ class Playlists(GObject.GObject):
                                       WHERE playlist_id=?", (playlist_id,))
                 return list(itertools.chain(*result))
 
-    def get_tracks_ids(self, playlist_id):
+    def get_track_ids(self, playlist_id):
         """
-            Return availables tracks id for playlist
+            Return availables track ids for playlist
             If playlist name == Type.ALL, then return all tracks from db
             @param playlist id as int
             @return array of track id as int
@@ -217,6 +219,28 @@ class Playlists(GObject.GObject):
                 return v[0]
             return ''
 
+    def get_names(self, playlist_ids):
+        """
+            Return playlist names
+            @param playlist_ids as [int]
+            @return names as [str]
+        """
+        names = []
+        for playlist_id in playlist_ids:
+            if playlist_id == Type.POPULARS:
+                names.append(_("Popular tracks"))
+            elif playlist_id == Type.RECENTS:
+                names.append(_("Recently played"))
+            elif playlist_id == Type.NEVER:
+                names.append(_("Never played"))
+            elif playlist_id == Type.RANDOMS:
+                names.append(_("Random tracks"))
+            elif playlist_id == Type.SEARCH:
+                names.append(_("Search"))
+            else:
+                names.append(self.get_name(playlist_id))
+        return names
+
     def clear(self, playlist_id, notify=True):
         """
             Clear playlsit
@@ -278,7 +302,7 @@ class Playlists(GObject.GObject):
             @return position as int
         """
         i = 0
-        for tid in self.get_tracks_ids(playlist_id):
+        for tid in self.get_track_ids(playlist_id):
             if track_id == tid:
                 break
             i += 1
@@ -304,30 +328,22 @@ class Playlists(GObject.GObject):
                 return True
             return False
 
-    def exists_album(self, playlist_id, album_id, genre_id):
+    def exists_album(self, playlist_id, album_id, genre_ids, artist_ids):
         """
             Return True if object_id is already present in playlist
             @param playlist id as int
             @param album id as int
-            @parma genre id as int
+            @param genre ids as [int]
+            @param artist ids as [int]
             @param sql as sqlite cursor
             @return bool
         """
         # We do not use Album object for performance reasons
         playlist_paths = self.get_tracks(playlist_id)
-        tracks_paths = Lp().albums.get_tracks_path(album_id,
-                                                   genre_id)
-        found = 0
-        len_tracks = len(tracks_paths)
-        for filepath in tracks_paths:
-            if filepath in playlist_paths:
-                found += 1
-                if found >= len_tracks:
-                    break
-        if found == len_tracks:
-            return True
-        else:
-            return False
+        track_paths = Lp().albums.get_tracks_path(album_id,
+                                                  genre_ids,
+                                                  artist_ids)
+        return len(set(playlist_paths) & set(track_paths)) == len(track_paths)
 
     def get_cursor(self):
         """
@@ -336,6 +352,7 @@ class Playlists(GObject.GObject):
         try:
             sql = sqlite3.connect(self.DB_PATH, 600.0)
             sql.execute("ATTACH DATABASE '%s' AS music" % Database.DB_PATH)
+            sql.create_collation('LOCALIZED', LocalizedCollation())
             return sql
         except:
             exit(-1)
