@@ -12,11 +12,14 @@
 
 from gi.repository import Gtk
 
-from lollypop.define import Lp, WindowSize
+from pickle import load
+
+from lollypop.define import Lp, WindowSize, DataPath
 from lollypop.toolbar_playback import ToolbarPlayback
-from lollypop.toolbar_infos import ToolbarInfos
+from lollypop.toolbar_info import ToolbarInfo
 from lollypop.toolbar_title import ToolbarTitle
 from lollypop.toolbar_end import ToolbarEnd
+from lollypop.utils import debug
 
 
 class Toolbar(Gtk.HeaderBar):
@@ -34,14 +37,14 @@ class Toolbar(Gtk.HeaderBar):
         self.set_title("Lollypop")
         self._toolbar_playback = ToolbarPlayback()
         self._toolbar_playback.show()
-        self._toolbar_infos = ToolbarInfos()
-        self._toolbar_infos.show()
+        self._toolbar_info = ToolbarInfo()
+        self._toolbar_info.show()
         self._toolbar_title = ToolbarTitle()
         self._toolbar_title.show()
         self._toolbar_end = ToolbarEnd(app)
         self._toolbar_end.show()
         self.pack_start(self._toolbar_playback)
-        self.pack_start(self._toolbar_infos)
+        self.pack_start(self._toolbar_info)
         self.set_custom_title(self._toolbar_title)
         self.pack_end(self._toolbar_end)
 
@@ -58,7 +61,7 @@ class Toolbar(Gtk.HeaderBar):
         """
         style = self.get_style_context()
         padding = style.get_padding(style.get_state())
-        info_height = self._toolbar_infos.get_preferred_height()
+        info_height = self._toolbar_info.get_preferred_height()
         if info_height[0]+padding.top+padding.bottom > 47:
             height = info_height[0]+padding.top+padding.bottom
         else:
@@ -79,9 +82,9 @@ class Toolbar(Gtk.HeaderBar):
         """
         width = self._toolbar_playback.get_preferred_width()[1]
         if window_width < WindowSize.MONSTER:
-            self._toolbar_infos.hide()
+            self._toolbar_info.hide()
         else:
-            self._toolbar_infos.show()
+            self._toolbar_info.show()
         if window_width < WindowSize.BIG:
             self._toolbar_end.hide()
         else:
@@ -97,7 +100,7 @@ class Toolbar(Gtk.HeaderBar):
                     title = available
                 self._toolbar_title.set_width(title)
                 if window_width >= WindowSize.MEDIUM:
-                    self._toolbar_infos.set_width((available-title)/2)
+                    self._toolbar_info.set_width((available-title)/2)
             self._width = window.get_width()
 
     def update_position(self, value=None):
@@ -114,6 +117,24 @@ class Toolbar(Gtk.HeaderBar):
         """
         self._toolbar_end.setup_menu(menu)
 
+    def set_mark(self):
+        """
+            Mark toolbar with previously saved position
+        """
+        try:
+            if Lp().settings.get_value('save-state'):
+                position = load(open(DataPath + "/position.bin", "rb"))
+                self._toolbar_title.add_mark(position/1000000)
+        except Exception as e:
+            print("Toolbar::restore_state():", e)
+
+    @property
+    def artsize(self):
+        """
+            Art size as int
+        """
+        return self._toolbar_info.artsize
+
 #######################
 # PRIVATE             #
 #######################
@@ -122,8 +143,9 @@ class Toolbar(Gtk.HeaderBar):
             Update toolbar
             @param player as Player
         """
+        debug("Toolbar::_on_current_changed")
         self._toolbar_playback.on_current_changed(player)
-        self._toolbar_infos.on_current_changed(player)
+        self._toolbar_info.on_current_changed(player)
         self._toolbar_title.on_current_changed(player)
 
     def _on_prev_changed(self, player):
