@@ -38,7 +38,6 @@ class View(Gtk.Grid):
         self._new_ids = []
 
         self._scrolled = Gtk.ScrolledWindow()
-        self._scrolled.connect('leave-notify-event', self._on_leave_event)
         self._scrolled.show()
         self._viewport = Gtk.Viewport()
         self._scrolled.add(self._viewport)
@@ -58,11 +57,11 @@ class View(Gtk.Grid):
         """
         GLib.idle_add(self._update_widgets, self._get_children())
 
-    def update_overlays(self):
+    def disable_overlays(self):
         """
-            Update overlays
+            Disable children's overlay
         """
-        GLib.idle_add(self._update_overlays, self._get_children())
+        GLib.idle_add(self._disable_overlays, self._get_children())
 
     def populate(self):
         pass
@@ -70,26 +69,15 @@ class View(Gtk.Grid):
 #######################
 # PRIVATE             #
 #######################
-    def _on_leave_event(self, widget, event):
+    def _disable_overlays(self, widgets):
         """
-            Update children's overlay
-        """
-        allocation = widget.get_allocation()
-        if event.x < 5 or\
-           event.x > allocation.width - 5 or\
-           event.y < 5 or\
-           event.y > allocation.height - 5:
-            self._update_overlays(self._get_children())
-
-    def _update_overlays(self, widgets):
-        """
-            Update children's overlay
+            Disable children's overlay
             @param widgets as AlbumWidget
         """
         if widgets:
             widget = widgets.pop(0)
-            widget.update_overlay()
-            GLib.idle_add(self._update_overlays, widgets)
+            widget.set_overlay(False)
+            GLib.idle_add(self._disable_overlays, widgets)
 
     def _update_widgets(self, widgets):
         """
@@ -127,7 +115,8 @@ class View(Gtk.Grid):
             @param album id as int
         """
         for widget in self._get_children():
-            widget.update_cover(album_id)
+            if album_id == widget.get_id():
+                widget.update_cover()
 
     def _on_current_changed(self, player):
         """
@@ -149,7 +138,7 @@ class LazyLoadingView(View):
         View.__init__(self)
         self._lazy_queue = []  # Widgets not initialized
         self._scroll_value = 0
-        self._timeout_id = None
+        self._prev_scroll_value = 0
         self._scrolled.get_vadjustment().connect('value-changed',
                                                  self._on_value_changed)
 
@@ -170,7 +159,7 @@ class LazyLoadingView(View):
         """
         widget = None
         if self._stop or self._scroll_value != scroll_value:
-            return
+            return False
         if widgets:
             widget = widgets.pop(0)
             self._lazy_queue.remove(widget)
@@ -178,10 +167,10 @@ class LazyLoadingView(View):
             widget = self._lazy_queue.pop(0)
         if widget is not None:
             widget.populate()
-            if self._timeout_id is None:
-                GLib.idle_add(self.lazy_loading, widgets, scroll_value)
+            if widgets:
+                GLib.timeout_add(10, self.lazy_loading, widgets, scroll_value)
             else:
-                GLib.timeout_add(50, self.lazy_loading, widgets, scroll_value)
+                GLib.idle_add(self.lazy_loading, widgets, scroll_value)
 
 #######################
 # PRIVATE             #
@@ -195,18 +184,17 @@ class LazyLoadingView(View):
         scrolled_alloc = self._scrolled.get_allocation()
         try:
             (x, y) = widget.translate_coordinates(self._scrolled, 0, 0)
-            return (y > -widget_alloc.height-ArtSize.BIG or y >= 0) and\
-                y < scrolled_alloc.height+ArtSize.BIG
+            return (y > -widget_alloc.height or y >= 0) and\
+                y < scrolled_alloc.height
         except:
             return True
 
-    def _lazy_or_not(self, adj):
+    def _lazy_or_not(self, scroll_value):
         """
             Add visible widgets to lazy queue
-            @param adj as Gtk.Adjustment
+            @param scroll value as float
         """
-        self._timeout_id = None
-        self._scroll_value = adj.get_value()
+        self._scroll_value = scroll_value
         widgets = []
         for child in self._lazy_queue:
             if self._is_visible(child):
@@ -218,9 +206,12 @@ class LazyLoadingView(View):
             Update scroll value and check for lazy queue
             @param adj as Gtk.Adjustment
         """
-        if self._timeout_id is not None:
-            GLib.source_remove(self._timeout_id)
-            self._timeout_id = None
         if not self._lazy_queue:
-            return
-        self._timeout_id = GLib.timeout_add(250, self._lazy_or_not, adj)
+            return False
+        wanted = ArtSize.BIG * self.get_scale_factor()
+        scroll_value = adj.get_value()
+        diff = self._prev_scroll_value - scroll_value
+        if diff > wanted or diff < -wanted:
+            self._prev_scroll_value = scroll_value
+            GLib.idle_add(self._lazy_or_not,
+                          scroll_value)
