@@ -12,7 +12,7 @@
 
 from gi.repository import Gtk, GLib, GObject
 
-from lollypop.view import LazyLoadingView
+from lollypop.view import LazyLoadingView, View
 from lollypop.view_container import ViewContainer
 from lollypop.define import Lp, Type
 from lollypop.objects import Track
@@ -212,13 +212,28 @@ class CurrentArtistAlbumsView(ViewContainer):
             Populate view and make it visible
             @param albums as [albums ids as int]
         """
+        # Add a loading indicator
+        view = View()
+        spinner = Gtk.Spinner()
+        spinner.set_hexpand(True)
+        spinner.set_vexpand(True)
+        spinner.set_size_request(100, 100)
+        spinner.set_property('halign', Gtk.Align.CENTER)
+        spinner.set_property('valign', Gtk.Align.CENTER)
+        spinner.start()
+        view.add(spinner)
+        view.show_all()
+        self.add(view)
+        self.set_transition_type(Gtk.StackTransitionType.NONE)
+        self.set_visible_child(view)
+        self.set_transition_type(Gtk.StackTransitionType.CROSSFADE)
+        self.clean_old_views(view)
+
         # Populate artist albums view
         view = ArtistAlbumsView(self._track.album.artist_ids, [])
+        view.connect('populated', self._on_populated, spinner)
         view.show()
         view.populate(albums)
-        self.add(view)
-        self.set_visible_child(view)
-        self.clean_old_views(view)
 
     def _get_albums(self):
         """
@@ -230,3 +245,14 @@ class CurrentArtistAlbumsView(ViewContainer):
         else:
             albums = Lp().artists.get_albums(self._track.album.artist_ids)
         return albums
+
+    def _on_populated(self, view, spinner):
+        """
+            Show the view
+            @param view as View
+            @param spinner as Gtk.Spinner
+        """
+        spinner.stop()
+        self.add(view)
+        self.set_visible_child(view)
+        self.clean_old_views(view)
