@@ -383,15 +383,19 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         self._cover = Gtk.Image()
         self._cover.set_property('halign', Gtk.Align.CENTER)
         self._cover.get_style_context().add_class('cover-frame')
-        self._title_label = Gtk.Label()
-        self._title_label.set_ellipsize(Pango.EllipsizeMode.END)
-        self._title_label.set_property('halign', Gtk.Align.CENTER)
-        self._title_label.set_markup("<b>"+escape(self._album.name)+"</b>")
-        self._artist_label = Gtk.Label()
-        self._artist_label.set_ellipsize(Pango.EllipsizeMode.END)
-        self._artist_label.set_property('halign', Gtk.Align.CENTER)
-        self._artist_label.set_text(", ".join(self._album.artists))
-        self._artist_label.get_style_context().add_class('dim-label')
+        title_label = Gtk.Label()
+        title_label.set_ellipsize(Pango.EllipsizeMode.END)
+        title_label.set_property('halign', Gtk.Align.CENTER)
+        title_label.set_markup("<b>"+escape(self._album.name)+"</b>")
+        title_label.set_property('has-tooltip', True)
+        title_label.connect('query-tooltip', self._on_query_tooltip)
+        artist_label = Gtk.Label()
+        artist_label.set_ellipsize(Pango.EllipsizeMode.END)
+        artist_label.set_property('halign', Gtk.Align.CENTER)
+        artist_label.set_text(", ".join(self._album.artists))
+        artist_label.get_style_context().add_class('dim-label')
+        artist_label.set_property('has-tooltip', True)
+        artist_label.connect('query-tooltip', self._on_query_tooltip)
         self._widget.add(grid)
         overlay = Gtk.Overlay.new()
         overlay.set_property('halign', Gtk.Align.CENTER)
@@ -410,8 +414,8 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
         color.get_style_context().add_class('white')
         color.add(overlay)
         grid.add(color)
-        grid.add(self._title_label)
-        grid.add(self._artist_label)
+        grid.add(title_label)
+        grid.add(artist_label)
         self.add(self._widget)
         self.set_cover()
         self.update_state()
@@ -550,14 +554,15 @@ class AlbumSimpleWidget(Gtk.FlowBoxChild, AlbumWidget):
             @param keyboard as bool
             @param tooltip as Gtk.Tooltip
         """
-        layout_title = self._title_label.get_layout()
-        layout_artist = self._artist_label.get_layout()
-        if layout_title.is_ellipsized() or layout_artist.is_ellipsized():
-            artist = escape(self._artist_label.get_text())
-            title = escape(self._title_label.get_text())
-            self.set_tooltip_markup("<b>%s</b>\n%s" % (artist, title))
+        layout = widget.get_layout()
+        if layout.is_ellipsized():
+            if widget.get_use_markup():
+                text = "<b>%s</b>" % escape(widget.get_text())
+            else:
+                text = escape(widget.get_text())
+            widget.set_tooltip_markup(text)
         else:
-            self.set_tooltip_text('')
+            widget.set_tooltip_text('')
 
 
 class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
@@ -611,7 +616,7 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
         rating = RatingWidget(self._album)
         rating.show()
 
-        self._artist_label = builder.get_object('artist')
+        artist_label = builder.get_object('artist')
         if show_cover:
             self._cover = builder.get_object('cover')
             builder.get_object('duration').set_hexpand(True)
@@ -624,15 +629,15 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
             if Lp().window.get_view_width() < WindowSize.MEDIUM:
                 self._coverbox.hide()
             if len(artist_ids) > 1:
-                self._artist_label.set_text(", ".join(self._album.artists))
-                self._artist_label.show()
+                artist_label.set_text(", ".join(self._album.artists))
+                artist_label.show()
         else:
             builder.get_object('header').attach(rating, 4, 0, 1, 1)
             rating.set_hexpand(True)
             rating.set_property('halign', Gtk.Align.END)
             rating.set_property('valign', Gtk.Align.CENTER)
-            self._artist_label.set_text(", ".join(self._album.artists))
-            self._artist_label.show()
+            artist_label.set_text(", ".join(self._album.artists))
+            artist_label.show()
             self._cover = None
 
         label = builder.get_object('duration')
@@ -879,7 +884,9 @@ class AlbumDetailedWidget(Gtk.Bin, AlbumWidget):
             return
         self._width = allocation.width
         redraw = False
-        if allocation.width < WindowSize.MONSTER:
+        if allocation.width < WindowSize.MEDIUM or (
+                allocation.width < WindowSize.MONSTER and
+                self._cover is not None):
             orientation = Gtk.Orientation.VERTICAL
         else:
             orientation = Gtk.Orientation.HORIZONTAL
